pub struct FallbackChainService { /* private fields */ }Expand description
A ScrapingService that tries multiple inner services in priority order,
automatically routing around open circuit breakers and failed services.
Construct via FallbackChainService::builder().
Example
use std::sync::Arc;
use std::time::Duration;
use stygian_graph::adapters::fallback::FallbackChainService;
use stygian_graph::adapters::noop::NoopService;
use stygian_graph::adapters::resilience::CircuitBreakerImpl;
use stygian_graph::ports::ScrapingService;
let chain = FallbackChainService::builder()
.add(Arc::new(NoopService), CircuitBreakerImpl::new(5, Duration::from_secs(60)))
.build();
assert_eq!(chain.name(), "fallback-chain");Implementations
Sourceimpl FallbackChainService
impl FallbackChainService
Sourcepub const fn builder() -> FallbackChainBuilder
pub const fn builder() -> FallbackChainBuilder
Return a FallbackChainBuilder for ergonomic construction.
Example
use stygian_graph::adapters::fallback::FallbackChainService;
let builder = FallbackChainService::builder();Sourcepub const fn len(&self) -> usize
pub const fn len(&self) -> usize
Return the number of services in this chain.
Example
use std::sync::Arc;
use std::time::Duration;
use stygian_graph::adapters::fallback::FallbackChainService;
use stygian_graph::adapters::noop::NoopService;
use stygian_graph::adapters::resilience::CircuitBreakerImpl;
let chain = FallbackChainService::builder()
.add(Arc::new(NoopService), CircuitBreakerImpl::new(3, Duration::from_secs(30)))
.add(Arc::new(NoopService), CircuitBreakerImpl::new(3, Duration::from_secs(30)))
.build();
assert_eq!(chain.len(), 2);Sourcepub const fn is_empty(&self) -> bool
pub const fn is_empty(&self) -> bool
Return true when no services are registered.
An empty chain always returns ServiceError::Unavailable.
Example
use stygian_graph::adapters::fallback::FallbackChainService;
let chain = FallbackChainService::builder().build();
assert!(chain.is_empty());Trait Implementations
Sourceimpl ScrapingService for FallbackChainService
impl ScrapingService for FallbackChainService
Sourcefn execute<'life0, 'async_trait>(
&'life0 self,
input: ServiceInput,
) -> Pin<Box<dyn Future<Output = Result<ServiceOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn execute<'life0, 'async_trait>(
&'life0 self,
input: ServiceInput,
) -> Pin<Box<dyn Future<Output = Result<ServiceOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Execute the fallback chain.
Tries each registered service in order, respecting circuit breaker state. Returns the first successful result, or the last error if all services fail.