pub struct NoopCircuitBreaker;Expand description
No-op circuit breaker for testing
Always reports Closed state and ignores all state transitions. Useful for testing scenarios where circuit breaker behavior should be disabled.
Example
use stygian_graph::adapters::resilience::NoopCircuitBreaker;
use stygian_graph::ports::{CircuitBreaker, CircuitState};
let cb = NoopCircuitBreaker;
cb.record_failure();
assert_eq!(cb.state(), CircuitState::Closed);Trait Implementations
Sourceimpl CircuitBreaker for NoopCircuitBreaker
impl CircuitBreaker for NoopCircuitBreaker
Sourcefn state(&self) -> CircuitState
fn state(&self) -> CircuitState
Sourcefn record_success(&self)
fn record_success(&self)
Sourcefn record_failure(&self)
fn record_failure(&self)
Sourcefn attempt_reset(&self) -> bool
fn attempt_reset(&self) -> bool
Sourceimpl Clone for NoopCircuitBreaker
impl Clone for NoopCircuitBreaker
Sourcefn clone(&self) -> NoopCircuitBreaker
fn clone(&self) -> NoopCircuitBreaker
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NoopCircuitBreaker
impl Debug for NoopCircuitBreaker
Sourceimpl Default for NoopCircuitBreaker
impl Default for NoopCircuitBreaker
Sourcefn default() -> NoopCircuitBreaker
fn default() -> NoopCircuitBreaker
impl Copy for NoopCircuitBreaker