pub struct NoopRateLimiter;Expand description
No-op rate limiter for testing
Always allows requests and ignores all rate limit tracking. Useful for testing scenarios where rate limiting should be disabled.
Example
use stygian_graph::adapters::resilience::NoopRateLimiter;
use stygian_graph::ports::RateLimiter;
let limiter = NoopRateLimiter;
assert!(limiter.check_rate_limit("any_key").await.unwrap());Trait Implementations
Sourceimpl Clone for NoopRateLimiter
impl Clone for NoopRateLimiter
Sourcefn clone(&self) -> NoopRateLimiter
fn clone(&self) -> NoopRateLimiter
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NoopRateLimiter
impl Debug for NoopRateLimiter
Sourceimpl Default for NoopRateLimiter
impl Default for NoopRateLimiter
Sourcefn default() -> NoopRateLimiter
fn default() -> NoopRateLimiter
Sourceimpl RateLimiter for NoopRateLimiter
impl RateLimiter for NoopRateLimiter
impl Copy for NoopRateLimiter