pub enum HealthStatus {
Healthy,
Degraded(String),
Unhealthy(String),
}Expand description
The health status of a single component.
Variants
Healthy
Component is operating normally.
Degraded(String)
Component is partially impaired but still serving requests.
Unhealthy(String)
Component is non-functional; requests will fail.
Implementations
Sourceimpl HealthStatus
impl HealthStatus
Sourcepub const fn is_healthy(&self) -> bool
pub const fn is_healthy(&self) -> bool
Returns true only when the component is fully healthy.
Example
use stygian_graph::application::health::HealthStatus;
assert!(HealthStatus::Healthy.is_healthy());
assert!(!HealthStatus::Degraded("latency".into()).is_healthy());Sourcepub const fn is_operational(&self) -> bool
pub const fn is_operational(&self) -> bool
Returns true when the component can still serve requests (healthy or degraded).
Example
use stygian_graph::application::health::HealthStatus;
assert!(HealthStatus::Healthy.is_operational());
assert!(HealthStatus::Degraded("high latency".into()).is_operational());
assert!(!HealthStatus::Unhealthy("connection refused".into()).is_operational());Trait Implementations
Sourceimpl Clone for HealthStatus
impl Clone for HealthStatus
Sourcefn clone(&self) -> HealthStatus
fn clone(&self) -> HealthStatus
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for HealthStatus
impl Debug for HealthStatus
Sourceimpl<'de> Deserialize<'de> for HealthStatus
impl<'de> Deserialize<'de> for HealthStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Display for HealthStatus
impl Display for HealthStatus
Sourceimpl PartialEq for HealthStatus
impl PartialEq for HealthStatus
Sourceimpl Serialize for HealthStatus
impl Serialize for HealthStatus
impl Eq for HealthStatus
impl StructuralPartialEq for HealthStatus